<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  Validatorクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    Pocket
 */
class Pocket_Validator
{
    /** @var    array   errors              エラーメッセージ情報配列 */
    var $errors = array();

    /**
     *  コンストラクタ
     *
     *  @access public
     */
    function Pocket_Validator()
    {
    }

    /**
     *  検証
     *
     *  @access public
     *  @param  string  $key                キー
     *  @param  string  $name               名称
     *  @param  string  $value              値
     *  @param  string  $type               型
     *                                      （number、numeric、alnum、email、url、ipaddress、zip、tel、string）
     *                                      上記以外の文字列は正規表現文字列として扱われます
     *  @param  boolean $required           必須フラグ
     *  @param  integer $min                最小値
     *  @param  integer $max                最大値
     */
    function validate($key, $name, $value, $type = 'string', $required = false, $min = NULL, $max = NULL)
    {
        // 必須チェック
        if (isset($required) && $required)
        {
            if (!$this->is_required($value))
            {
                $this->errors[$key] = $name . 'は必須入力です。';
                return false;
            }
        }

        // 型チェック
        if (isset($type))
        {
            if ($type == 'number')
            {
                // 数値チェック
                if ($value && !$this->is_number($value))
                {
                    $this->errors[$key] = $name . 'に半角数値以外の文字が含まれています。';
                    return false;
                }
            }
            else if ($type == 'numeric') {
                // 数値文字列チェック
                if ($value && !$this->is_numeric($value))
                {
                    $this->errors[$key] = $name . 'は数値ではありません。';
                    return false;
                }
            }
            else if ($type == 'alnum') {
                // 半角英数チェック
                if ($value && !$this->is_alnum($value))
                {
                    $this->errors[$key] = $name . 'に半角英数以外の文字が含まれています。';
                    return false;
                }
            }
            else if ($type == 'email') {
                // メールアドレスチェック
                if ($value && !$this->is_email($value))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
            else if ($type == 'url') {
                // URLチェック
                if ($value && !$this->is_url($value))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
            else if ($type == 'ipaddress') {
                // IPアドレスチェック
                if ($value && !$this->is_ipaddress($value))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
            else if ($type == 'zip') {
                // 郵便番号チェック
                if ($value && !$this->is_zip($value))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
            else if ($type == 'tel') {
                // 電話番号チェック
                if ($value && !$this->is_tel($value))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
            else if ($type == 'string') {
            }
            else {
                // 正規表現チェック
                if ($value && !$this->is_regexp($value, $type))
                {
                    $this->errors[$key] = $name . 'は正しい形式ではありません。';
                    return false;
                }
            }
        }

        // 範囲チェック
        if (isset($min) || isset($max))
        {
            if (!$this->is_range($value, $min, $max))
            {
                $this->errors[$key] = $name . 'の範囲が不正です。';
                return false;
            }
        }

        return true;
    }

    /**
     *  必須チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_required($value)
    {
        if ($value == NULL || (is_string($value) && strlen($value) == 0) || (is_array($value) && count($value)))
        {
            return false;
        }
        return true;
    }

    /**
     *  数値チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_number($value)
    {
        if (!preg_match('/^[0-9]+$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  数値文字列チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_numeric($value)
    {
        if (!is_numeric($value))
        {
            return false;
        }
        return true;
    }

    /**
     *  半角英数チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_alnum($value)
    {
        if (!preg_match('/^[\w]+$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  メールアドレスチェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_email($value)
    {
        if (!preg_match('/^[\w\-\.]+@[\w\-]+(\.[\w\-]+)+$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  URLチェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_url($value)
    {
        if (!preg_match('/^(https?|http)(:\/\/[-_.!~*\'()\w;\/?:\@&=+\$,%#]+)$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  IPアドレスチェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_ipaddress($value)
    {
        if (long2ip(ip2long($value)) != $value)
        {
            return false;
        }
        return true;
    }

    /**
     *  郵便番号チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_zip($value)
    {
        if (!preg_match('/^\d{3}\-\d{4}$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  電話番号チェック
     *
     *  @access public
     *  @param  string  $value              値
     */
    function is_tel($value)
    {
        if (!preg_match('/^\d{2,4}\-\d{2,4}\-\d{4}$/', $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  正規表現チェック
     *
     *  @access public
     *  @param  string  $value              値
     *  @param  string  $type               正規表現
     */
    function is_regexp($value, $type)
    {
        if (!preg_match($type, $value))
        {
            return false;
        }
        return true;
    }

    /**
     *  範囲チェック
     *
     *  @access public
     *  @param  string  $value              値
     *  @param  integer $min                最小値
     *  @param  integer $max                最大値
     */
    function is_range($value, $min, $max)
    {
        if (isset($min) && $value < $min)
        {
            return false;
        }
        else if (isset($max) && $value > $max)
        {
            return false;
        }
        return true;
    }

    /**
     *  エラーメッセージの追加
     *
     *  @access public
     *  @param  string  $key                キー
     *  @param  string  $value              値
     */
    function addErrors($key, $value)
    {
        $this->errors[$key] = $value;
    }

    /**
     *  エラーメッセージのクリア
     *
     *  @access public
     */
    function clearErrors()
    {
        $this->errors = array();
    }

    /**
     *  有効チェック
     *
     *  @access public
     *  @return boolean true,false
     */
    function isValid()
    {
        if (count($this->errors))
        {
            return false;
        }
        return true;
    }
}

?>
