<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  Actionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBBS
 */
class Pocket_Bbs_Action extends Pocket_Action
{
    /**
     *  コンストラクタ
     *
     *  @access public
     */
    function Pocket_Bbs_Action()
    {
        // 親クラスのコンストラクタ
        parent::Pocket_Action();
        // ユーザIDを初期化（未設定の場合は、初期登録ユーザのIDを設定）
        if (!isset($_SESSION['user_id'])) {$_SESSION['user_id'] = db_get_user4first_user_id();}
    }

    /**
     *  サイドメニュー情報をテンプレート変数に設定
     *
     *  @access public
     */
    function assignSideMenuInfo()
    {
        // セッション情報の取得
        $user_id = $_SESSION['user_id'];

        // カテゴリ情報の取得
        $category_list = db_get_categories4children(0);
        // カテゴリリストのトピック件数を設定する
        $this->setTopicsCount4Category(&$category_list);
        // カテゴリ情報の設定
        $this->smarty->assign('category_list', $category_list);
        // 最新のトピック情報の取得、設定
        $this->smarty->assign('latest_topic_list', db_get_topics4latest_topic_list(1, NEWS_SIZE));
        // 最新のコメント情報の取得、設定
        $this->smarty->assign('latest_comment_list', db_get_topic_comments4latest_comment_list(1, NEWS_SIZE));
        // リンク情報の取得、設定
        $this->smarty->assign('link_list', db_get_links4link_list());
        // 未確認のコメント件数の取得、設定
        $this->smarty->assign('unchecked_comment_count', db_get_topic_comments_count4unchecked());
        
        // 本日のアクセス件数の取得、設定
        $count = db_get_accessCount4day(0);
        $this->smarty->assign('access_count_today', $count);
        $this->smarty->assign('access_count_today_assoc', pocket_getCountAssoc($count, 6));
        // 昨日のアクセス件数の取得、設定
        $count = db_get_accessCount4day(-1);
        $this->smarty->assign('access_count_yesterday', $count);
        $this->smarty->assign('access_count_yesterday_assoc', pocket_getCountAssoc($count, 6));
        // 累計のアクセス件数の取得、設定
        $count = db_get_accessCount4total();
        $this->smarty->assign('access_count_total', $count);
        $this->smarty->assign('access_count_total_assoc', pocket_getCountAssoc($count, 6));

        // バナー情報（ランダム）の取得、設定
        $this->smarty->assign('banner_list', db_get_banner4random(1, NEWS_SIZE));
    }

    /**
     *  カテゴリのパン屑リスト情報をテンプレート変数に設定
     *
     *  @access public
     *  @param  integer $category_id        カテゴリID
     */
    function assignCategoryBreadcrumbsListInfo($category_id)
    {
        // カテゴリのパン屑リスト情報の取得、設定
        $this->smarty->assign('breadcrumbs_list', $this->_getCategoryBreadcrumbsListInfo($category_id));
    }

    /**
     *  カテゴリのパン屑リスト情報を取得する
     *
     *  @access public
     *  @param  integer $category_id        カテゴリID
     */
    function _getCategoryBreadcrumbsListInfo($category_id)
    {
        static $categories = array();

        // カテゴリ情報を取得
        $row = db_get_category($category_id);

        // 親カテゴリの存在チェック
        if ($row['parent_id'] != 0)
        {
            // 配列の先頭に追加
            array_unshift($categories, $row);
            // 再帰呼出し
            $this->_getCategoryBreadcrumbsListInfo($row['parent_id']);
        }
        else {
            // 配列の先頭に追加
            array_unshift($categories, $row);
        }

        return $categories;
    }

    /**
     *  カテゴリリストのトピック件数を設定する
     *
     *  @access public
     *  @param  array   $category_list      カテゴリリスト
     */
    function setTopicsCount4Category(&$category_list)
    {
        // カテゴリでループ
        foreach ($category_list as $key => $category)
        {
            // カテゴリのトピック件数を設定する
            $category_list[$key]['topics_count'] = $this->_getTopicsCount4Category($category['category_id']);
        }
    }

    /**
     *  カテゴリのトピック件数を取得する
     *
     *  @access public
     *  @param  integer $category_id        カテゴリID
     *  @param  boolean $initialize         初期化フラグ
     */
    function _getTopicsCount4Category($category_id, $initialize = true)
    {
        static $topics_count = 0;
        
        // カウンタの初期化
        if ($initialize)
            $topics_count = 0;

        // カテゴリのトピック件数の取得
        $topics_count += db_get_topics_count4category($category_id);

        // カテゴリの子ノード情報の取得
        $children = db_get_categories4children($category_id);

        // カテゴリの子ノードでループ
        foreach ($children as $child)
        {
            // 再帰呼出し
            $this->_getTopicsCount4Category($child['category_id'], false);
        }

        return $topics_count;
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return false;
    }
}

?>
